@@ -4,7 +4,7 @@ from datetime import datetime, time
 from django import forms
 from django.utils.dateparse import parse_datetime
 from django.utils.encoding import force_str
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .conf import settings
 from .constants import EMPTY_VALUES
@@ -14,7 +14,7 @@ from .widgets import (
     CSVWidget,
     DateRangeWidget,
     LookupChoiceWidget,
-    RangeWidget
+    RangeWidget,
 )
 
 
@@ -23,9 +23,7 @@ class RangeField(forms.MultiValueField):
 
     def __init__(self, fields=None, *args, **kwargs):
         if fields is None:
-            fields = (
-                forms.DecimalField(),
-                forms.DecimalField())
+            fields = (forms.DecimalField(), forms.DecimalField())
         super().__init__(fields, *args, **kwargs)
 
     def compress(self, data_list):
@@ -38,9 +36,7 @@ class DateRangeField(RangeField):
     widget = DateRangeWidget
 
     def __init__(self, *args, **kwargs):
-        fields = (
-            forms.DateField(),
-            forms.DateField())
+        fields = (forms.DateField(), forms.DateField())
         super().__init__(fields, *args, **kwargs)
 
     def compress(self, data_list):
@@ -48,13 +44,11 @@ class DateRangeField(RangeField):
             start_date, stop_date = data_list
             if start_date:
                 start_date = handle_timezone(
-                    datetime.combine(start_date, time.min),
-                    False
+                    datetime.combine(start_date, time.min), False
                 )
             if stop_date:
                 stop_date = handle_timezone(
-                    datetime.combine(stop_date, time.max),
-                    False
+                    datetime.combine(stop_date, time.max), False
                 )
             return slice(start_date, stop_date)
         return None
@@ -64,9 +58,7 @@ class DateTimeRangeField(RangeField):
     widget = DateRangeWidget
 
     def __init__(self, *args, **kwargs):
-        fields = (
-            forms.DateTimeField(),
-            forms.DateTimeField())
+        fields = (forms.DateTimeField(), forms.DateTimeField())
         super().__init__(fields, *args, **kwargs)
 
 
@@ -74,9 +66,7 @@ class IsoDateTimeRangeField(RangeField):
     widget = DateRangeWidget
 
     def __init__(self, *args, **kwargs):
-        fields = (
-            IsoDateTimeField(),
-            IsoDateTimeField())
+        fields = (IsoDateTimeField(), IsoDateTimeField())
         super().__init__(fields, *args, **kwargs)
 
 
@@ -84,13 +74,11 @@ class TimeRangeField(RangeField):
     widget = DateRangeWidget
 
     def __init__(self, *args, **kwargs):
-        fields = (
-            forms.TimeField(),
-            forms.TimeField())
+        fields = (forms.TimeField(), forms.TimeField())
         super().__init__(fields, *args, **kwargs)
 
 
-class Lookup(namedtuple('Lookup', ('value', 'lookup_expr'))):
+class Lookup(namedtuple("Lookup", ("value", "lookup_expr"))):
     def __new__(cls, value, lookup_expr):
         if value in EMPTY_VALUES or lookup_expr in EMPTY_VALUES:
             raise ValueError(
@@ -103,15 +91,15 @@ class Lookup(namedtuple('Lookup', ('value', 'lookup_expr'))):
 
 class LookupChoiceField(forms.MultiValueField):
     default_error_messages = {
-        'lookup_required': _('Select a lookup.'),
+        "lookup_required": _("Select a lookup."),
     }
 
     def __init__(self, field, lookup_choices, *args, **kwargs):
-        empty_label = kwargs.pop('empty_label', settings.EMPTY_CHOICE_LABEL)
+        empty_label = kwargs.pop("empty_label", settings.EMPTY_CHOICE_LABEL)
         fields = (field, ChoiceField(choices=lookup_choices, empty_label=empty_label))
         widget = LookupChoiceWidget(widgets=[f.widget for f in fields])
-        kwargs['widget'] = widget
-        kwargs['help_text'] = field.help_text
+        kwargs["widget"] = widget
+        kwargs["help_text"] = field.help_text
         super().__init__(fields, *args, **kwargs)
 
     def compress(self, data_list):
@@ -122,8 +110,8 @@ class LookupChoiceField(forms.MultiValueField):
                     return Lookup(value=value, lookup_expr=lookup_expr)
                 else:
                     raise forms.ValidationError(
-                        self.error_messages['lookup_required'],
-                        code='lookup_required')
+                        self.error_messages["lookup_required"], code="lookup_required"
+                    )
         return None
 
 
@@ -136,7 +124,8 @@ class IsoDateTimeField(forms.DateTimeField):
 
     Based on Gist example by David Medina https://gist.github.com/copitux/5773821
     """
-    ISO_8601 = 'iso-8601'
+
+    ISO_8601 = "iso-8601"
     input_formats = [ISO_8601]
 
     def strptime(self, value, format):
@@ -160,30 +149,42 @@ class BaseCSVField(forms.Field):
             pass
 
     """
+
     base_widget_class = BaseCSVWidget
 
     def __init__(self, *args, **kwargs):
-        widget = kwargs.get('widget') or self.widget
-        kwargs['widget'] = self._get_widget_class(widget)
+        widget = kwargs.get("widget") or self.widget
+        kwargs["widget"] = self._get_widget_class(widget)
 
         super().__init__(*args, **kwargs)
 
     def _get_widget_class(self, widget):
         # passthrough, allows for override
         if isinstance(widget, BaseCSVWidget) or (
-                isinstance(widget, type) and
-                issubclass(widget, BaseCSVWidget)):
+            isinstance(widget, type) and issubclass(widget, BaseCSVWidget)
+        ):
             return widget
 
         # complain since we are unable to reconstruct widget instances
-        assert isinstance(widget, type), \
-            "'%s.widget' must be a widget class, not %s." \
-            % (self.__class__.__name__, repr(widget))
+        assert isinstance(
+            widget, type
+        ), "'%s.widget' must be a widget class, not %s." % (
+            self.__class__.__name__,
+            repr(widget),
+        )
 
-        bases = (self.base_widget_class, widget, )
-        return type(str('CSV%s' % widget.__name__), bases, {})
+        bases = (
+            self.base_widget_class,
+            widget,
+        )
+        return type(str("CSV%s" % widget.__name__), bases, {})
 
     def clean(self, value):
+        if value in self.empty_values and self.required:
+            raise forms.ValidationError(
+                self.error_messages["required"], code="required"
+            )
+
         if value is None:
             return None
         return [super(BaseCSVField, self).clean(v) for v in value]
@@ -194,9 +195,7 @@ class BaseRangeField(BaseCSVField):
     # input would only allow a user to input one value and would always fail.
     widget = CSVWidget
 
-    default_error_messages = {
-        'invalid_values': _('Range query expects two values.')
-    }
+    default_error_messages = {"invalid_values": _("Range query expects two values.")}
 
     def clean(self, value):
         value = super().clean(value)
@@ -205,13 +204,13 @@ class BaseRangeField(BaseCSVField):
 
         if value and len(value) != 2:
             raise forms.ValidationError(
-                self.error_messages['invalid_values'],
-                code='invalid_values')
+                self.error_messages["invalid_values"], code="invalid_values"
+            )
 
         return value
 
 
-class ChoiceIterator(object):
+class ChoiceIterator:
     # Emulates the behavior of ModelChoiceIterator, but instead wraps
     # the field's _choices iterable.
 
@@ -224,10 +223,7 @@ class ChoiceIterator(object):
             yield ("", self.field.empty_label)
         if self.field.null_label is not None:
             yield (self.field.null_value, self.field.null_label)
-
-        # Python 2 lacks 'yield from'
-        for choice in self.choices:
-            yield choice
+        yield from self.choices
 
     def __len__(self):
         add = 1 if self.field.empty_label is not None else 0
@@ -247,20 +243,17 @@ class ModelChoiceIterator(forms.models.ModelChoiceIterator):
             yield next(iterable)
         if self.field.null_label is not None:
             yield (self.field.null_value, self.field.null_label)
-
-        # Python 2 lacks 'yield from'
-        for value in iterable:
-            yield value
+        yield from iterable
 
     def __len__(self):
         add = 1 if self.field.null_label is not None else 0
         return super().__len__() + add
 
 
-class ChoiceIteratorMixin(object):
+class ChoiceIteratorMixin:
     def __init__(self, *args, **kwargs):
-        self.null_label = kwargs.pop('null_label', settings.NULL_CHOICE_LABEL)
-        self.null_value = kwargs.pop('null_value', settings.NULL_CHOICE_VALUE)
+        self.null_label = kwargs.pop("null_label", settings.NULL_CHOICE_LABEL)
+        self.null_value = kwargs.pop("null_value", settings.NULL_CHOICE_VALUE)
 
         super().__init__(*args, **kwargs)
 
@@ -272,6 +265,7 @@ class ChoiceIteratorMixin(object):
         value = self.iterator(self, self._choices)
 
         self._choices = self.widget.choices = value
+
     choices = property(_get_choices, _set_choices)
 
 
@@ -280,7 +274,7 @@ class ChoiceField(ChoiceIteratorMixin, forms.ChoiceField):
     iterator = ChoiceIterator
 
     def __init__(self, *args, **kwargs):
-        self.empty_label = kwargs.pop('empty_label', settings.EMPTY_CHOICE_LABEL)
+        self.empty_label = kwargs.pop("empty_label", settings.EMPTY_CHOICE_LABEL)
         super().__init__(*args, **kwargs)
 
 
